close all
clear 

%options
material = 'wool'; cloth_size = 'A2'; type = 'hitting'; inter_stick = true;
file_name = [material '_' cloth_size '_' type '.csv'];

%all data
A = readmatrix(file_name);

%markers labels
labels = A(2,3:end); labels_unique = unique(labels,'stable');

%remove the first non-informative rows
A = A(6:end,:); 

% read times and make times(1) = 0
times = A(:,2); times = times - times(1);

%XYZ coordinates of all recorded nodes
B = A(:,3:end); %avoid times and frames columns
n_coord = size(B,2); %total number of coordinates
n_nodes = n_coord/3; %total number of nodes
%split X Y and Z coordinates
ind_x = 1:3:n_coord; ind_y = ind_x + 1; ind_z = ind_y + 1; 
%switch Y and Z
xx = B(:,ind_x); zz = B(:,ind_y); yy = B(:,ind_z);

%triangulate the cloud
%mesh with respect labels_unique order
T0 = [1 5 6 2; 2 6 7 3;3 7 8 4; 5 9 10 6; 6 10 11 7; 7 11 12 8; 9 13 14 10;
    10 14 15 11; 11 15 16 12; 13 17 18 14; 14 18 19 15; 15 19 20 16];
%mesh with respect real ordering in X
T = 0*T0;
for e = 1:size(T0,1)
    Te = T0(e,:);
    for n=1:4
        ind_lab = find(Te(n) == labels_unique);
        T(e,n) = ind_lab;
    end    
end

%stick
E = [find(labels_unique == 21),find(labels_unique == 22)]; 
E = [E,E(2),E(2)]; %trick for plotting the stick
if inter_stick == true
   xx(:,E(1)) = fillmissing(xx(:,E(1)),'linear','SamplePoints',times);
   xx(:,E(2)) = fillmissing(xx(:,E(2)),'linear','SamplePoints',times);
   yy(:,E(1)) = fillmissing(yy(:,E(1)),'linear','SamplePoints',times);
   yy(:,E(2)) = fillmissing(yy(:,E(2)),'linear','SamplePoints',times);
   zz(:,E(1)) = fillmissing(zz(:,E(1)),'linear','SamplePoints',times);
   zz(:,E(2)) = fillmissing(zz(:,E(2)),'linear','SamplePoints',times);
end

%first frame
frm = 1; X = [xx(frm,:)',yy(frm,:)',zz(frm,:)'];
fig = trisurf([T;E],X(:,1),X(:,2),X(:,3),'edgecolor', 'k','facecolor','w');
xlim([-1 1]); zlim([-1 1]); ylim([-1 1]);
camzoom(2); axis off

%movie
for frm = 2:length(times)
    pause(0.25*(times(frm)-times(frm-1)))
    X = [xx(frm,:)',yy(frm,:)',zz(frm,:)'];
    fig.Vertices = X;
end

