close all
clear 

%options
material = 'polyester'; cloth_size = 'A2'; type = 'full'; friction = 'high';
file_name = [material '_' cloth_size '_' type '_lay_' friction '_friction.csv'];

%all data
A = readmatrix(file_name);

%markers labels
labels = A(2,3:end); labels_unique = unique(labels,'stable');

%remove the first non-informative rows
A = A(6:end,:); 

% read times and make times(1) = 0
times = A(:,2); times = times - times(1);

%XYZ coordinates of all recorded nodes
B = A(:,3:end); %avoid times and frames columns
n_coord = size(B,2); %total number of coordinates
n_nodes = n_coord/3; %total number of nodes
%split X Y and Z coordinates
ind_x = 1:3:n_coord; ind_y = ind_x + 1; ind_z = ind_y + 1; 
%switch Y and Z
xx = B(:,ind_x); zz = B(:,ind_y); yy = B(:,ind_z);

%triangulate the cloud
%mesh with respect labels_unique order
T0 = [1 6 7 2; 6 11 12 7; 11 16 17 12; 2 7 8 3; 7 12 13 8; 12 17 18 13;
      3 8 9 4; 8 13 14 9; 13 18 19 14; 4 9 10 5; 9 14 15 10;14 19 20 15];
%mesh with respect real ordering in X
T = 0*T0;
for e = 1:size(T0,1)
    Te = T0(e,:);
    for n=1:4
        ind_lab = find(Te(n) == labels_unique);
        T(e,n) = ind_lab;
    end    
end

%first frame
frm = 1; X = [xx(frm,:)',yy(frm,:)',zz(frm,:)'];
fig = trisurf(T,X(:,1),X(:,2),X(:,3),'edgecolor', 'k','facecolor','w');
xlim([-1 1]); zlim([-1 1]); ylim([-1 1]);
camzoom(2); axis off

%corners
frm = 100;
[~,ind1] = max(yy(frm,:)' + zz(frm,:)'); [~,ind2] = max(-yy(frm,:)' + zz(frm,:)');
crns_ind = [ind1,ind2];
%trajectories
u = [xx(:,crns_ind(1)),yy(:,crns_ind(1)),zz(:,crns_ind(1)),...
     xx(:,crns_ind(2)),yy(:,crns_ind(2)),zz(:,crns_ind(2))];

%movie
for frm = 2:length(times)
    pause(0.25*(times(frm)-times(frm-1)))
    X = [xx(frm,:)',yy(frm,:)',zz(frm,:)'];
    fig.Vertices = X;
end

%plot corners' trajectories
hold on
scatter3(u(:,1),u(:,2),u(:,3))
scatter3(u(:,4),u(:,5),u(:,6))
hold off



